"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestError = void 0;
const grpc_js_1 = require("@grpc/grpc-js");
/**
 * Utility class to create errors for gRPC requests
 */
class RequestError extends Error {
    /**
     * Error status code
     */
    code;
    /**
     * Error details
     */
    details;
    /**
     * Request metadata
     */
    metadata;
    /**
     * Creates custom error for gRPC requests
     * @param code Status code representing the error
     * @param request ProtoRequest instance which triggered this error
     * @param details Error details (message)
     */
    constructor(code, request, details) {
        if (!details) {
            if (code === grpc_js_1.status.CANCELLED) {
                details = `Cancelled ${request.requestMethodType} for '${request.method}'`;
            }
            else if (code === grpc_js_1.status.DEADLINE_EXCEEDED) {
                details = `${request.requestMethodType} for '${request.method}' timed out`;
            }
            else {
                details = `${code} ${grpc_js_1.status[code]}: ${request.requestMethodType} for '${request.method}'`;
            }
        }
        super(details);
        this.code = code;
        this.details = details;
        this.metadata = request.metadata;
    }
}
exports.RequestError = RequestError;
//# sourceMappingURL=RequestError.js.map