"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileBuilder = void 0;
const fs_1 = require("fs");
const cli_color_1 = __importDefault(require("cli-color"));
/**
 * File building util used in cli
 */
class FileBuilder {
    filePath = "";
    lines = [];
    indentation = [];
    constructor(filePath) {
        this.filePath = filePath;
    }
    get contents() {
        return this.lines.join("\n");
    }
    push(...lines) {
        const indent = this.indentation.join("");
        lines.forEach((line) => this.lines.push(indent + line));
    }
    pushWithIndent(...lines) {
        this.indent();
        this.push(...lines);
        this.deindent();
    }
    indent() {
        this.indentation.push(`\t`);
    }
    deindent() {
        if (this.indentation.length) {
            this.indentation.pop();
        }
    }
    newline() {
        this.lines.push(``);
    }
    async write() {
        const filename = this.filePath.split(/\//g).pop();
        try {
            await fs_1.promises.writeFile(this.filePath, this.contents, `utf-8`);
            console.log(cli_color_1.default.green(`✔ ${filename}`));
        }
        catch (e) {
            console.log(cli_color_1.default.red(`✖ Failed to write ${filename}`));
            console.error(e);
            process.exit(1);
        }
    }
}
exports.FileBuilder = FileBuilder;
//# sourceMappingURL=FileBuilder.js.map